//========================================================================================
//
//	File:				FormPane.cpp
//	Release Version:	$ 1.0d11 $
//
//	Author:				Laurent Delamare
//
//	Copyright:	 1993, 1995 by Apple Computer, Inc., all rights reserved.
//
//========================================================================================

#include "Form.hpp"

#ifndef FORMPANE_H
#include "FormPane.h"
#endif

#ifndef FORMDEF_H
#include "FormDef.h"
#endif

#ifndef FORMPART_H
#include "FormPrt.h"
#endif

// ----- Framework Layer -----

#ifndef FWUTIL_H
#include "FWUtil.h"
#endif

#ifndef FWFRAME_H
#include "FWFrame.h"
#endif

// ----- OS Layer -----

#ifndef FWRECT_H
#include "FWRect.h"
#endif

#ifndef FWRECSHP_H
#include "FWRecShp.h"
#endif

#ifndef FWACQUIR_H
#include "FWAcquir.h"
#endif

#ifndef FWODGEOM_H
#include "FWODGeom.h"
#endif

#ifndef FWRGNSHP_H
#include "FWRgnShp.h"
#endif

// ----- OpenDoc Includes -----

#ifndef SOM_Module_OpenDoc_Commands_defined
#include <CmdDefs.xh>
#endif

#ifndef SOM_Module_OpenDoc_StdProps_defined
#include <StdProps.xh>
#endif

#ifndef SOM_ODSession_xh
#include <ODSessn.xh>
#endif

#ifndef SOM_ODDispatcher_xh
#include <Disptch.xh>
#endif

//========================================================================================
// RunTime Info
//========================================================================================

#ifdef FW_BUILD_MAC
#pragma segment odfform
#endif

FW_DEFINE_CLASS_M1(CFormPane, FW_CView);

//========================================================================================
// CFormPane
//========================================================================================

//----------------------------------------------------------------------------------------
// CFormPane::CFormPane
//----------------------------------------------------------------------------------------

CFormPane::CFormPane(Environment* ev, FW_CView* container, FW_CRect& bounds, CFormPart* part) :
	FW_CView(ev, container, bounds),
	fFormPart(part)
{	
}

//----------------------------------------------------------------------------------------
// CFormPane::~CFormPane
//----------------------------------------------------------------------------------------

CFormPane::~CFormPane()
{
}

//----------------------------------------------------------------------------------------
// CFormPane::Draw
//----------------------------------------------------------------------------------------

void CFormPane::Draw(Environment *ev, ODFacet* odFacet, ODShape* invalidShape)
{
	// Set the drawing context for this view (all drawing will be done in local
	// coordinates for this view)
	FW_CViewContext vc(ev, this, odFacet, invalidShape);

	// Draw a gray background outside the content view (to avoid flashing during
	// updates when the content scrolls)
	FW_CRect paneRect(FW_kZeroPoint, GetSize(ev)); 
	FW_CRect contentRect(GetFrame(ev)->GetContentView(ev)->GetBounds(ev));
	FW_CAcquiredODShape aqPaneShape = ::FW_NewODShape(ev, paneRect);
	FW_CAcquiredODShape aqContentShape = ::FW_NewODShape(ev, contentRect);
	aqPaneShape->Subtract(ev, aqContentShape);

	FW_CRegionShape::RenderRegion(vc, aqPaneShape, FW_kFill, FW_kRGBLightGray);
	FW_CRectShape::RenderRect(vc, paneRect, FW_kFrame, FW_kRGBBlack); 

	// Draw a 1 pixel frame around the content view
	contentRect.Inset(-FW_IntToFixed(1),-FW_IntToFixed(1));
 	FW_CRectShape::RenderRect(vc, contentRect, FW_kFrame);
}

